if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallCenter_ControlEvents' ) )
	drop table dbo.A_CallCenter_ControlEvents
GO

Create table dbo.A_CallCenter_ControlEvents 
(
	Id uniqueidentifier not null primary key,
	Name nvarchar ( 100 ),
	Type int,
	Type2 int,
	Active bit,
	Stream image,
	IsDeleted bit
)
GO

if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallCenter_ControlEvents_LoadAll' ) )
	drop procedure dbo.A_CallCenter_ControlEvents_LoadAll
GO

Create procedure dbo.A_CallCenter_ControlEvents_LoadAll
as
begin

	Select Id, Type, Type2, Active, DataLength(Stream) as Length, Stream 
	From A_CallCenter_ControlEvents
	Where IsDeleted = 0
end
GO



if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_CallCenter_UserStateHistory_GetToday' ) )
	drop procedure dbo.A_CallCenter_UserStateHistory_GetToday
GO

Create procedure dbo.A_CallCenter_UserStateHistory_GetToday
	@dtnow datetime = null
as
begin

	if ( @dtnow is null )
		Set @dtnow = GetDate()

	declare @dttoday datetime
	set @dttoday = cast ( Floor ( cast ( @dtnow as float ) ) as DateTime )

	Select OperatorId, Sum ( Cast ( IsNull ( TimeLeave, @dtnow ) - case when ( TimeEnter < @dttoday ) then @dttoday else TimeEnter end as float ) ) 
	From A_CallCenter_UserStateHistory
	Where ( TimeLeave is null or TimeLeave > @dttoday )
		And State = 3
	Group By OperatorId

end
GO


if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallCenter_ControlEvents_UpdateActive' ) )
	drop procedure dbo.A_CallCenter_ControlEvents_UpdateActive
GO

Create procedure dbo.A_CallCenter_ControlEvents_UpdateActive
	@idevent uniqueidentifier,
	@active bit
as
begin

	Update A_CallCenter_ControlEvents
	Set Active = @active
	Where Id = @idevent
end
GO


if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallCenter_ControlEventsJournal' ) )
	drop table dbo.A_CallCenter_ControlEventsJournal
GO

Create table dbo.A_CallCenter_ControlEventsJournal 
(
	Id int identity ( 1, 1 ) primary key,
	IdEvent uniqueidentifier,
	EventDateTime DateTime,
	EventDate DateTime,
	EventTime DateTime,
	ValStr nvarchar ( 100 ),
	ValDec decimal, 
	IdTask uniqueidentifier,
	IdOperator uniqueidentifier,	
	Comment nvarchar ( 3000 )
)
GO


if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallCenter_ControlEvents_AddExecutedData' ) )
	drop procedure dbo.A_CallCenter_ControlEvents_AddExecutedData
GO

Create procedure dbo.A_CallCenter_ControlEvents_AddExecutedData
	@idevent uniqueidentifier,
	@valstr nvarchar ( 100 ),
	@valdec decimal,
	@idtask uniqueidentifier,
	@idoperator uniqueidentifier,
	@comment nvarchar ( 3000 ) = '',
	@dtnow datetime = null
as
begin
	if ( @dtnow is null )
		set @dtnow = GetDate()

	declare @time datetime, @date datetime
	set @date = Cast ( Floor ( Cast ( @dtnow as float ) ) as DateTime )
	set @time = Cast ( ( Cast ( @dtnow as float ) - cast ( @time as float ) ) as DateTime )

	Insert into A_CallCenter_ControlEventsJournal
	Values ( @idevent, @dtnow, @date, @time, @valstr, @valdec, @idtask, @idoperator, @comment )
end
GO


if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallCenter_ControlEvents_GetJournal' ) )
	drop procedure dbo.A_CallCenter_ControlEvents_GetJournal
GO

Create procedure dbo.A_CallCenter_ControlEvents_GetJournal
	@iduser uniqueidentifier,
	@datestart datetime,
	@datestop datetime,
	@timestart datetime,
	@timestop datetime,
	@idsevent nvarchar ( 4000 ),
	@idstask nvarchar ( 4000 ),
	@idsoperator nvarchar ( 4000 )
as
begin
	Declare @dstart datetime, @tstart datetime, @dstop datetime, @tstop datetime
	Set @dstart = Cast ( Floor ( Cast ( @datestart as float ) ) as DateTime )
	Set @dstop = Cast ( Floor ( Cast ( @datestop as float ) ) as DateTime )
	Set @tstart = Cast ( Cast ( @timestart as float ) - Floor ( Cast ( @timestart as float ) ) as DateTime )
	Set @tstop = Cast ( Cast ( @timestop as float ) - Floor ( Cast ( @timestop as float ) ) as DateTime )

	declare @temp nvarchar ( 4000 )
	declare @tempid uniqueidentifier

	Declare @events table ( id uniqueidentifier )
	Declare @tasks table ( id uniqueidentifier )
	Declare @operators table ( id uniqueidentifier )

	set @temp = @idsevent
	if ( len ( @temp ) > 1 )
		while ( len ( @temp ) > 1 )
		begin
			select Substring ( @temp, 1, 36 )
			set @tempid = cast ( Substring ( @temp, 1, 36 )	 as uniqueidentifier )
			insert into @events values ( @tempid )
			set @temp = substring ( @temp, 38, len ( @temp ) - 37 )
		end	
	else
		Insert into @events
			Select Id 
			From A_CallCenter_ControlEvents
			Where IsDeleted = 0


	set @temp = @idstask
	if ( len ( @temp ) > 1 )
		while ( len ( @temp ) > 1 )
		begin
			select Substring ( @temp, 1, 36 )
			set @tempid = cast ( Substring ( @temp, 1, 36 )	 as uniqueidentifier )
			insert into @tasks values ( @tempid )
			set @temp = substring ( @temp, 38, len ( @temp ) - 37 )
		end
	else
		Insert into @tasks
			Select Id 
			From A_TaskManager_Tasks

	set @temp = @idsoperator
	if ( len ( @temp ) > 1 )
		while ( len ( @temp ) > 1 )
		begin
			select Substring ( @temp, 1, 36 )
			set @tempid = cast ( Substring ( @temp, 1, 36 )	 as uniqueidentifier )
			insert into @operators values ( @tempid )
			set @temp = substring ( @temp, 38, len ( @temp ) - 37 )
		end
	else
		Insert into @operators
			Select Id 
			From A_Users
	

	Select j.Id, j.IdEvent, ce.Name as EventName, j.EventDateTime, j.ValStr, j.ValDec, j.IdTask, ti.Name as TaskName, j.IdOperator, oi.Name as OperatorName
	From A_CallCenter_ControlEventsJournal j
		Inner join A_CallCenter_ControlEvents ce on j.IdEvent = ce.Id
		Inner join @events e on j.IdEvent = e.Id
		Inner join @tasks t on j.IdTask = t.Id
		Inner join @operators o on j.IdOperator = o.Id
		Left join A_TaskManager_Tasks ti on ti.Id = t.Id
		Left join A_Users oi on oi.Id = o.Id
	Where ( EventDate > @dstart ) and ( EventDate < @dstop )
		and ( EventTime > @tstart ) and ( EventTime < @tstop )
	
end
GO


if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallCenter_ControlEvents_Delete' ) )
	drop procedure dbo.A_CallCenter_ControlEvents_Delete
GO

Create procedure dbo.A_CallCenter_ControlEvents_Delete
	@idevent uniqueidentifier
as
begin
	Delete
	From A_CallCenter_ControlEvents
	Where id = @idevent
end
GO



if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallCenter_ControlEvents_Save' ) )
	drop procedure dbo.A_CallCenter_ControlEvents_Save
GO

Create procedure dbo.A_CallCenter_ControlEvents_Save
	@id uniqueidentifier,
	@name nvarchar ( 100 ),
	@type int,
	@type2 int,
	@active bit,
	@stream image,
	@isdeleted bit = 0
as
begin
	Select id 
	From A_CallCenter_ControlEvents
	Where id = @id

	if ( @@rowcount > 0 )
		Update A_CallCenter_ControlEvents
		Set 	Id = @id,
			Name = @name,
			Type = @type,
			Type2 = @type2,
			Active = @active,
			Stream = @stream,
			IsDeleted = @isdeleted
		Where Id = @id
	else
		Insert into A_CallCenter_ControlEvents
		Values ( @id, @name, @type, @type2, @active, @stream, @isdeleted )
end
GO
