if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_ServerStreams' ) )
	Drop table dbo.A_ServerStreams
GO

Create table dbo.A_ServerStreams 
( 	Id uniqueidentifier Primary key, 
	Name nvarchar ( 500 ), 
	IdServer uniqueidentifier,
	Type int default 0
)
GO

if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Admin_OfficeMap_ServerStream_Clear' ) )
	drop procedure dbo.A_Admin_OfficeMap_ServerStream_Clear
GO

Create procedure dbo.A_Admin_OfficeMap_ServerStream_Clear
as
begin
	Delete From A_ServerStreams;
end
GO

if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Admin_OfficeMap_ServerStream_Set' ) )
	drop procedure dbo.A_Admin_OfficeMap_ServerStream_Set
GO

Create procedure dbo.A_Admin_OfficeMap_ServerStream_Set
	@id uniqueidentifier,
	@name nvarchar ( 500 ),
	@idserver uniqueidentifier,
	@type int
as
begin
	Insert into A_ServerStreams ( Id, Name, IdServer, Type )
	Values ( @id, @name, @idserver, @type )
end
GO


if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Admin_OfficeMap_ServerStream_Get' ) )
	drop procedure dbo.A_Admin_OfficeMap_ServerStream_Get
GO

Create procedure dbo.A_Admin_OfficeMap_ServerStream_Get
	@idserver uniqueidentifier
as
begin
	if ( @idserver = '00000000-0000-0000-0000-000000000000' )
		Select Id, Name, IdServer, Type 
		From A_ServerStreams	
	else
		Select Id, Name, IdServer, Type 
		From A_ServerStreams
		Where IdServer = @idserver
end
GO

if exists ( Select * FROM sysobjects where Id = Object_Id ( 'dbo.A_ServerExtLines' ) )
if not Exists ( Select * From INFORMATION_SCHEMA.Columns Where TABLE_NAME like 'A_ServerExtLines' 
								and TABLE_SCHEMA like 'dbo'
								and COLUMN_NAME like 'StreamId' )
	Alter Table dbo.A_ServerExtLines
	Add StreamId uniqueidentifier
GO


if exists ( Select * FROM sysobjects where Id = Object_Id ( 'dbo.A_ServerSipLines' ) )
if not Exists ( Select * From INFORMATION_SCHEMA.Columns Where TABLE_NAME like 'A_ServerSipLines' 
								and TABLE_SCHEMA like 'dbo'
								and COLUMN_NAME like 'StreamId' )
	Alter Table dbo.A_ServerSipLines
	Add StreamId uniqueidentifier
GO



if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_Admin_Lines_Int_Get' ) )
	drop procedure dbo.A_Admin_Lines_Int_Get
GO

CREATE Procedure [dbo].A_Admin_Lines_Int_Get
	@id	uniqueidentifier
as
begin
   --    .
   --  0  - 
   --    -   (  CTI)

   Declare @groups table ( groupid uniqueidentifier, groupname nvarchar ( 255 ) collate database_default)
   Insert into @groups
	Select Id, Name 
	From A_Groups
   Insert Into @groups ( groupid, groupname )
	Values ( '00000000-0000-0000-0000-000000000000', '' )


   if ( @id = '00000000-0000-0000-0000-000000000000' )
   begin
	Select 
		e.Id,
		w.Name,
		w.Id,
		Cast ( e.SystemNum as nvarchar(20) ) as SystemNum,
		Cast ( e.Enabled as bit ) as Enabled,		
		Cast ( e.CityStraight as bit ) as CityStraight, 
		e.caption,
		e.ServerId,
		e.Type,
		e.ParentGroupId,
		g.GroupName,
		e.Address,
		e.StreamId	
	FROM 
	(	
		Select 	Id,
			systemnum, 
			enabled, 
			citystraight, 
			caption, 
			ServerID,
			Type,
			ParentGroupId,
			'' as Address,
			NULL as StreamId
		From A_ServerIntLines

		Union All

		Select 	Id,
			systemnum, 
			enabled, 
			citystraight, 
			caption, 
			ServerID,
			Type,
			ParentGroupId,
			'' as Address,
			NULL as StreamId
		From A_ServerUsbLines
		
		Union All

		Select 	Id,
			systemnum, 
			enabled, 
			citystraight, 
			caption, 
			ServerID,
			Type,
			ParentGroupId,
			Address,
			StreamId
		From A_ServerSipLines
	) e
	
	Inner join A_WorkPlaces w on e.ServerID = w.ID
	Inner join @groups g on e.ParentGroupId = g.GroupId
	Order By SystemNum
    
   end
   else
   begin
	
	Select 
		e.Id,
		w.Name,
		w.Id,
		Cast ( e.SystemNum as nvarchar(20) ) as SystemNum,
		Cast ( e.Enabled as bit ) as Enabled,		
		Cast ( e.CityStraight as bit ) as CityStraight, 
		e.caption,
		e.ServerId,
		e.Type,
		e.ParentGroupId,
		g.GroupName,
		e.Address,
		e.StreamId
	
	FROM 
	(	
		Select 
			Id,
			systemnum, 
			enabled, 
			citystraight, 
			caption, 
			ServerID,
			Type,
			ParentGroupId,
			'' as Address,
			NULL as StreamId
		From A_ServerIntLines
		
	) e
	
	Inner join A_WorkPlaces w on e.ServerID = w.ID
	Inner join @groups g on e.ParentGroupId = g.GroupId
	Where e.ServerId = @id
	Order By SystemNum
    end	

end
GO



if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_Admin_Lines_Ext_Get' ) )
	drop procedure dbo.A_Admin_Lines_Ext_Get
GO

Create Procedure [dbo].A_Admin_Lines_Ext_Get
	@id	uniqueidentifier
as
begin

	Select 	
		e.Id,		
		w.Name, 
		w.Id,
		Cast ( e.SystemNum as nvarchar(20) ) as SystemNum,
		Cast ( e.Enabled as bit ) as Enabled, 
		Cast ( e.CanSimpleOut as bit ) as CanSimpleOut,
		Cast ( e.CanIp as bit ) as CanIp, 
		Cast ( e.CanAutoDial as bit ) as CanAutoDial,
		Cast ( e.CanMobile as bit ) as CanMobile, 
		e.Prefix,
		e.ExtNumber,
		e.Caption,
		e.DialType,
		e.ConnectedPBX,
		e.Type,
		e.StreamId
	
	From A_ServerExtLines e 
		Inner Join A_WorkPlaces w on e.ServerID = w.ID

	Where ( e.ServerID = @id ) or ( @id = '00000000-0000-0000-0000-000000000000' )

	Order By SystemNum
end
GO
