if exists ( Select * From sysobjects Where id = object_id ( 'dbo.A_CallCenter_GetResourceInfo' ) )
	drop procedure dbo.A_CallCenter_GetResourceInfo
GO

Create procedure [dbo].[A_CallCenter_GetResourceInfo]
	@minutes int,
	@dtnow datetime = null
as
begin

--  :
--  -   ( )
--  -   ()
--  -   ()
--  -    ()
--  -  ( )
--  -    ( )

--declare @minutes int
--set @minutes = 5

----------------------------------------------------------------------
--   ---------------------------------------------
----------------------------------------------------------------------
	Declare @intervalsec int 
	set @intervalsec = @minutes * 60

	if ( @dtnow is null )
		Set @dtnow = GetDate()

	Declare @dtstart DateTime
	Set @dtstart = DateAdd ( mi, - @minutes, @dtnow )

	Declare @operators table ( id uniqueidentifier )
	Insert into @operators
		Select IdUser FROM A_UserParams
		Where IsOperator = 1

	Declare @tasks table ( id uniqueidentifier, name nvarchar ( 200 ) collate database_default, IsOutput bit, projectname nvarchar ( 200 ) collate database_default)
	Insert into @tasks
		Select t.Id, t.Name, t.IsOutputTask, p.Name 
		From A_TaskManager_Tasks t
			Inner join A_TaskManager_Projects p on t.IdProject = p.Id
		Where Active = 1 
			and Done = 0 
			and StartRunDateTime < @dtnow
			and StopRunDateTime > @dtnow
			and CreationType = 2
		order by idproject, type

	
	Declare @taskoperators table (idtask uniqueidentifier, idoperator uniqueidentifier)
	Insert into @taskoperators
		Select TaskId, OperatorId 
		From A_TaskManager_Operators taskopers
			Inner join @operators opers on taskopers.OperatorId = opers.Id

	Declare @tasklinecount table (idtask uniqueidentifier, linecount int )
	Insert into @tasklinecount
		Select TaskId, Count ( * ) 
		From A_TaskManager_TaskExtLines el
			Inner join @tasks t on t.Id = el.TaskId
		Group By TaskId
		
		Union all
	
		Select Id, IncomingCallsMaxCount
		From A_TaskManager_Tasks
		Where IsOutputTask = 0	

	Declare @extlines table ( id uniqueidentifier, name nvarchar ( 100 ) collate database_default)
	Insert into @extlines
		Select Id, SystemNum From A_ServerExtLines


	declare @tempopers table ( idoperator uniqueidentifier, idtask uniqueidentifier, datetimestart datetime, datetimestop datetime, LenTime float )
	Insert into @tempopers
		Select idoperator, idtask, datetimestart, datetimestop, lentime
		From oktell_cc_temp.dbo.A_Cube_CC_OperatorStates os --With ( TabLock )
		Where DateTimeStop > @dtstart
		and not os.idtask is null

	declare @tempconn table ( IdConn uniqueidentifier, IdTask uniqueidentifier, IdExtLine uniqueidentifier, DateTimeStart datetime, DateTimeStop datetime, LenTime float, IsOutput bit )
	Insert into @tempconn
		Select IdConn, IdTask, IdExtLine, DateTimeStart, DateTimeStop, LenTime, IsOutput
		From oktell_cc_temp.dbo.A_Cube_CC_EffortConnections sc with ( INDEX ( idxCubeConnections_DateTimeStop ) ) --With ( TabLock )
		Where DateTimeStop > @dtstart


	Update @tempopers
	Set DateTimeStart = @dtstart
	Where DateTimeStart < @dtstart

	Update @tempopers
	Set DateTimeStop = @dtnow
	Where DateTimeStop > @dtnow or DateTimeStop is null

	Update @tempopers
	Set LenTime = Cast ( DateTimeStop - DateTimeStart as float ) * 86400

	Update @tempconn
	Set DateTimeStart = @dtstart
	Where DateTimeStart < @dtstart

	Update @tempconn
	Set DateTimeStop = @dtnow
	Where DateTimeStop > @dtnow or DateTimeStop is null

	Update @tempconn
	Set LenTime = Cast ( DateTimeStop - DateTimeStart as float ) * 86400


	declare @output table ( Type int, Id uniqueidentifier, Val float, Name nvarchar ( 100 ) collate database_default, ExtName nvarchar ( 100 ) collate database_default)
		

----------------------------------------------------------------------
--   -----------------------------------------------
----------------------------------------------------------------------


	Insert into @output ( Type, Id, Val )
		Select 1, IdOperator, Sum ( LenTime ) / @intervalsec * 100 as Val
		From
		(
			--   
			Select IdOperator, LenTime
			From @tempopers
	
			Union all
	
			--   
			Select id, 0
			From @operators o
		)a
			Inner join @operators o on a.IdOperator = o.Id
		Group By IdOperator


----------------------------------------------------------------------
--   ----------------------------------------------------
----------------------------------------------------------------------
	
	declare @temp51 table ( ALineId uniqueidentifier, BLineId uniqueidentifier, DateTimeStart datetime, DateTimeStop datetime, LenTime float, IdChain uniqueidentifier )
	Insert into @temp51
		Select ALineId, BLineId, TimeStart, TimeStop, 0, IdChain
		From A_Stat_Connections_1x1 sc with ( Index  ( idx_StatConn_TStart_TStop ) ) --With ( TabLock )
		Where TimeStop > @dtstart or TimeStop is null

	Update @temp51
	Set DateTimeStart = @dtstart
	Where DateTimeStart < @dtstart

	Update @temp51
	Set DateTimeStop = @dtnow
	Where DateTimeStop > @dtnow or DateTimeStop is null

	Update @temp51
	Set LenTime = Cast ( DateTimeStop - DateTimeStart as float ) * 86400


	declare @temp52 table ( IdExtLine uniqueidentifier, DateTimeStart datetime, DateTimeStop datetime, LenTime float )
	Insert into @temp52
		Select el.Id, DateTimeStart, DateTimeStop, LenTime
		From @temp51 sc
			Inner join @extlines el on sc.ALineId = el.Id or sc.BLineId = el.Id



	declare @temp5 table ( IdExtLine uniqueidentifier, DateTimeStart datetime, DateTimeStop datetime, LenTime float )
	/*
	insert into @temp5
		--          A_Stat_Connections  IVR
		--       .
		Select IdExtLine, DateTimeStart, DateTimeStop, LenTime
		From @tempconn 
		Where IdConn is null and IsOutput = 1

		Union all
	
		Select IdExtLine, DateTimeStart, DateTimeStop, LenTime
		From @temp52
	*/

	--    .        .
	--   ) , )     .
	--     ,   , ( )  ( )  -  ,          ..
	--   ,                . -  ,     .

	-- c    .
	declare @temp53 table ( IdExtLine uniqueidentifier, DateTimeStart datetime, DateTimeStop datetime, LenTime float )
	insert into @temp53
		Select l.Id as IdExtLine, Min ( DateTimeStart ) as DateTimeStart, Max ( DateTimeStop ) as DateTimeStop, 0
		From @extlines l
			Inner join @temp51 sc on sc.ALineId = l.Id or sc.BLineId = l.Id
		Group by l.Id, IdChain
	
	Update @temp53
	Set LenTime = Cast ( DateTimeStop - DateTimeStart as float ) * 86400

	insert into @temp5
		--          A_Stat_Connections  IVR
		--       .
		Select IdExtLine, DateTimeStart, DateTimeStop, LenTime
		From @tempconn 
		Where IdConn is null and IsOutput = 1

		Union all

		Select * FROM @temp53
			

	Insert into @output ( Type, Id, Val )
		Select 2, IdExtLine, Sum ( LenTime ) / @intervalsec * 100 as Val
		From
		(
			Select IdExtLine, LenTime
			From @temp5

			Union all

			Select Id, 0
			From @extlines
		) a
			Inner join @extlines el on a.IdExtLine = el.Id
		Group By IdExtLine 

----------------------------------------------------------------------
--    -----------------------------------
----------------------------------------------------------------------

	declare @taskrescount table ( idtask uniqueidentifier, cnt int )
	Insert into @taskrescount 
		Select idtask, sum ( rescnt )
		From
		(
			Select idtask, linecount as rescnt
			From @tasklinecount
	
			Union all

			Select idtask, count ( * ) as rescnt
			From @taskoperators
			Group By Idtask
		)a
		Group By idtask


	Declare @tempres table ( IdTask uniqueidentifier, SumLen float )
	Insert into @tempres
		Select IdTask, Sum ( LenTime )
		From
		(
			Select IdTask, LenTime 
			From @tempopers
			
			Union all
		
			Select IdTask, LenTime
			From @tempconn
			
			Union all 
		
			Select Id, 0
			From @tasks
		)b
		Group By IdTask


	Insert into @output ( Type, Id, Val )
		Select 3, tr.IdTask, case when (cnt = 0) then 0 else SumLen / ( cnt * @intervalsec ) * 100 end as Val
		From @tempres tr
			Inner join @taskrescount trc on tr.IdTask = trc.IdTask
			Inner join @tasks t on tr.IdTask = t.Id

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

	Update o
	Set o.Name = u.Name
	From @output o, A_Users u
	Where o.Id = u.Id and o.Type = 1

	Update o
	Set o.Name = el.Name
	From @output o, @extlines el
	Where o.Id = el.Id and o.Type = 2

	Update o
	Set o.Name = t.Name,
	    o.ExtName = t.ProjectName
	From @output o, @tasks t
	Where o.Id = t.Id and o.Type = 3


	Select * 
	From @output
	Order By Type, ExtName, Name

end
GO



if exists ( Select * From sysobjects Where id = object_id ( 'dbo.A_TaskManager_OperatorsAll_Get_DayTalkTime' ) )
	Drop procedure dbo.A_TaskManager_OperatorsAll_Get_DayTalkTime
GO


Create  procedure [dbo].[A_TaskManager_OperatorsAll_Get_DayTalkTime]
	@dtnow 			datetime = null
as
begin
	if ( @dtnow is null )
		Set @dtnow = GetDate()

	Select u.Id, Sum ( Convert ( float, TimeStop - TimeStart ) ) as DayTalks_Days
	From A_Stat_Connections_1x1 sc with ( Index  ( idx_StatConn_TStart_TStop ) ) --With ( TabLock )
		inner join A_Users u on sc.AUserId = u.Id or sc.BUserId = u.Id
	Where FLOOR ( cast ( @dtnow as float ) ) = FLOOR ( cast ( TimeStop as float ) )		
	Group by u.Id
	Order by DayTalks_Days
end
GO


if exists ( Select * From sysobjects Where id = object_id ( 'dbo.A_TaskManager_OperatorsAll_Get_FreeTime' ) )
	Drop procedure dbo.A_TaskManager_OperatorsAll_Get_FreeTime
GO

Create  procedure [dbo].[A_TaskManager_OperatorsAll_Get_FreeTime]
	@dtnow 			datetime = null
as
begin
	if ( @dtnow is null )
		Set @dtnow = GetDate()

	declare @ldt datetime
	set @ldt = DateAdd ( d, -2, @dtnow )

	Select u.id, 
		--Max ( TimeStop ) as TimeStop_Last,
		Convert ( float, @dtnow - Max ( IsNull ( TimeStop, @dtnow ) ) ) as MaxFreeTime_Days
	From A_Stat_Connections_1x1 sc with ( Index  ( idx_StatConn_TStart_TStop ) ) --With ( TabLock )
		Inner join A_USers u on sc.AUserId = u.id or sc.BUserId = u.Id	
	Where sc.TimeStart > @ldt
	Group by u.Id
	order by MaxFreeTime_Days desc
end
GO
