if exists ( select * from sysobjects where id = object_id ( 'dbo.A_IM_Messages' ) )
	Drop table dbo.A_IM_Messages
GO

CREATE TABLE dbo.[A_IM_Messages] (
	[Id] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Service] [int] NOT NULL,
	[Date_Sent] [datetime] NOT NULL CONSTRAINT [DF_A_IM_Messages_date_sent] DEFAULT (getdate()),
	[Date_Received] [datetime] NOT NULL CONSTRAINT [DF_A_IM_Messages_date_receive] DEFAULT (getdate()),
	[Date_Handled] [datetime],
	[Message] [nvarchar] (4000) COLLATE Cyrillic_General_CI_AS NOT NULL ,
	[Id_From] [varchar] (500) COLLATE Cyrillic_General_CI_AS NOT NULL ,
	[Id_To] [varchar] (500) COLLATE Cyrillic_General_CI_AS NOT NULL ,
	[IsUsed] [bit] NOT NULL CONSTRAINT [DF_A_IM_Messages_isused] DEFAULT (0)
) ON [PRIMARY]
GO


if exists ( select * from sysobjects where id = object_id ( 'dbo.A_IM_Messages' ) )
    if not exists ( select name from sysindexes where id=object_id('dbo.A_IM_Messages') and name = 'idxIMMessages_idto_isused_svc' )
	CREATE INDEX idxIMMessages_idto_isused ON dbo.A_IM_Messages
	(
		Id_To, IsUsed, Service
	) WITH FILLFACTOR = 80
GO

if exists ( select * from sysobjects where id = object_id ( 'dbo.A_IM_Messages' ) )
    if not exists ( select name from sysindexes where id=object_id('dbo.A_IM_Messages') and name = 'idxIMMessages_datesent' )
	CREATE INDEX idxIMMessages_datesent ON dbo.A_IM_Messages
	(
		Date_Sent
	) WITH FILLFACTOR = 80
GO


if exists ( select * from sysobjects where id = object_id ( 'dbo.A_IM_AddReceived' ) )
	Drop procedure dbo.A_IM_AddReceived
GO

Create procedure dbo.A_IM_AddReceived
	@@service int,
	@@id_from nvarchar ( 500 ),
	@@id_to nvarchar ( 500 ),
	@@message nvarchar ( 4000 ),
	@@date_sent DateTime,
	@@date_received DateTime
as
begin	
	Insert into A_IM_Messages
		( Service, Id_From, Id_To, Message, Date_Sent, Date_Received )
	Values
		( @@service, @@id_from, @@id_to, @@message, @@date_sent, @@date_received )
end
GO

if exists ( select * from sysobjects where id = object_id ( 'dbo.A_IM_GetFirstUnusedMessage' ) )
	Drop procedure dbo.A_IM_GetFirstUnusedMessage
GO

Create procedure dbo.A_IM_GetFirstUnusedMessage
	@@service int,
	@@id_to nvarchar ( 500 ),
	@@dtnow datetime = NULL
as
begin
	if ( @@dtnow = NULL )
		Set @@dtnow = GetDate()

	declare @id int
	declare @id_from nvarchar( 1000 )
	declare @message nvarchar( 4000 )
	declare @date datetime

	Begin tran GetFirstUnusedMessage

	Select top 1 @id = id
	From  A_IM_Messages
	Where ( Id_To = @@id_to ) and ( IsUsed = 0 ) and ( Service = @@service )
	Order by id asc

	--update A_IM_Messages
	--set IsUsed = 1, Date_Handled = @@dtnow
	--where id = @id

	Select top 1 @id_from = Id_From, @message = Message, @date = Date_Sent
	From  A_IM_Messages
	Where id = @id

	--Timely delete used position
	Delete A_IM_Messages
	Where id = @id

	if ( not @id_from is null )
		Select @id_from, @message, @date
	
	Commit tran GetFirstUnusedMessage
end
GO

