if exists ( select * from sysobjects where id = object_id ( 'dbo.A_TalkResults_Filter_Journal' ))
	Drop procedure dbo.A_TalkResults_Filter_Journal
GO

Create procedure [dbo].[A_TalkResults_Filter_Journal]
	@dstart 	datetime,
	@dstop 		datetime,
	@tstart 	datetime,
	@tstop 		datetime,
	@taskid 	uniqueidentifier,
	@number 	nvarchar ( 50 ),
	@operatorid	uniqueidentifier,
	@ResultValue int = NULL,
	@ResultMask int = NULL,
	@ResultText nvarchar(500) = NULL,
	@CardId uniqueidentifier,
	@showefforts	int
as
begin

	declare @tstart2 DateTime
	declare @tstop2 DateTime
	set @tstart2 = Cast ( Cast ( @tstart as float ) - Floor ( Cast ( @tstart as float ) ) as DateTime )
	set @tstop2 = Cast ( Cast ( @tstop as float ) - Floor ( Cast ( @tstop as float ) ) as DateTime )


	declare @tmp_card_result table(TaskId  uniqueidentifier, IdChain uniqueidentifier)
	delete 	@tmp_card_result

	if @ResultValue is not null
		Insert into @tmp_card_result(TaskId,IdChain)	
			Select IdTask, IdConnection
			From A_Stat_Talk_Algorythms sta
				inner join A_Stat_Talk_Card_Radio stcr on sta.IdAlgVisit=stcr.IdAlgVisit
			Where IdCard = @CardId and ChosenResult = @ResultValue


	if @ResultMask is not null 
	begin
		Insert into @tmp_card_result ( TaskId, IdChain )
			Select IdTask, IdConnection
			From A_Stat_Talk_Algorythms sta
				inner join A_Stat_Talk_Card_Check stcc on sta.IdAlgVisit = stcc.IdAlgVisit
				inner join A_BigInt big on big.K & ChosenResult = big.K
			Where IdCard = @CardId 
				and big.K = @ResultMask
	end


	if @ResultText is not null 
	begin
		Insert into @tmp_card_result(TaskId,IdChain)		
			Select IdTask, IdConnection
			From A_Stat_Talk_Algorythms sta
				inner join A_Stat_Talk_Card_Text stct on sta.IdAlgVisit=stct.IdAlgVisit
			Where IdCard=@CardId and ChosenResult=@ResultText
	end


	declare @te table ( EffortId uniqueidentifier, IdConn uniqueidentifier, IdChain uniqueidentifier, TaskId uniqueidentifier, IdOperator uniqueidentifier, Number nvarchar ( 50 ) collate database_default, CallTime DateTime, Result int, Info nvarchar ( 500 ) collate database_default, LenTime float, IsRecorded int, IdRecDir int, ALineNum nvarchar ( 5 ) collate database_default, BLineNum nvarchar ( 5 ) collate database_default) --ARecFile nvarchar ( 100 ), BRecFile nvarchar ( 100 ) )

	Insert into @te
		Select IdEffort, IdConn, IdChain, IdTask, IdOperator, AbonentNumber, DateTimeStart, CallResult, CallResultInfo, LenTime, IsRecorded, IdRecDir, ALineNum, BLineNum --ARecFile, BRecFile
		From [oktell_cc_temp].dbo.A_Cube_CC_EffortConnections ec --With ( TabLock )
		Where 	(DateStart between @dstart and @dstop)
			and (TimeStart between @tstart2 and @tstop2)
			and ec.IdTask = @taskid
			and AbonentNumber like '%' + @number + '%'
			and Exists ( Select IdChain From @tmp_card_result Where IdChain = ec.IdChain )


	Select te.IdConn as Id, te.IdChain, te.Number, IsNull ( u.Name, '?' ) as FullName, te.CallTime, case when ( len ( te.Info ) > 0 ) then ( trt.Name + ' (' + te.Info + ')') else trt.Name end as Info, Cast ( te.LenTime / 86400 as DateTime ) as Length, IsNull ( IsRecorded, 0 ) as IsRecorded, IsNull ( IdRecDir, 0 ) as IdRecDir, IsNull ( ALineNum, '') as ALineNum, IsNull ( BLineNum, '') as BLineNum --IsNull ( ARecFile, '' ) as ARecFile, IsNull ( BRecFile, '' ) as BRecFile 
	From @te te
		Left join A_Users u on u.Id = te.IdOperator
		Left join [oktell_cc_temp].[dbo].A_Cube_CC_Cat_TaskResultTypes trt on trt.Id = te.Result
	Where te.IdOperator is null or te.IdOperator != 'AB000000-0000-0000-0000-000000000000'

end
GO



if exists ( Select * from sysobjects where id = object_id ( 'dbo.A_TaskManager_List_DistrDirectDb_GetNumberHistory' ))
	Drop procedure dbo.A_TaskManager_List_DistrDirectDb_GetNumberHistory
GO

Create procedure dbo.A_TaskManager_List_DistrDirectDb_GetNumberHistory
	@taskid uniqueidentifier,
	@idinlist int,
	@number nvarchar ( 50 )
as
begin
	Select * From
	(
		Select Top 300 IdConn as ID, IdChain, IdEffort, DateTimeStart, LenTime, CallResult, UserResult, CallResultInfo, IsRecorded, IdRecDir, ALineNum, BLineNum
		From oktell_cc_temp.dbo.A_Cube_CC_EffortConnections ec
		Where IdTask = @taskid		
			And IdInList = @idinlist
			And AbonentNumber = @number
		Order By DateTimeStart Desc
	)a
	Order By DateTimeStart
end
GO

